#!/bin/bash

echo "[+] Copy toc-extension config to user-settings"
mkdir -p /home/jovyan/work/.jupyter_config/lab/user-settings/@jupyterlab/toc-extension
cp ./.user-settings/@jupyterlab/toc-extension/plugin.jupyterlab-settings /home/jovyan/work/.jupyter_config/lab/user-settings/@jupyterlab/toc-extension/plugin.jupyterlab-settings

echo "[+] Copy docmanager-extension config to user-settings"
mkdir -p /home/jovyan/work/.jupyter_config/lab/user-settings/@jupyterlab/docmanager-extension
cp ./.user-settings/@jupyterlab/docmanager-extension/plugin.jupyterlab-settings /home/jovyan/work/.jupyter_config/lab/user-settings/@jupyterlab/docmanager-extension/plugin.jupyterlab-settings

echo "[+] Copy filebrowser-extension config to user-settings"
mkdir -p /home/jovyan/work/.jupyter_config/lab/user-settings/@jupyterlab/filebrowser-extension
cp ./.user-settings/@jupyterlab/filebrowser-extension/browser.jupyterlab-settings /home/jovyan/work/.jupyter_config/lab/user-settings/@jupyterlab/filebrowser-extension/browser.jupyterlab-settings

echo "[+] Set theme"
mkdir -p /opt/conda/share/jupyter/lab/settings
cat << EOF > /opt/conda/share/jupyter/lab/settings/overrides.json
{
  "@jupyterlab/apputils-extension:themes": {
    "theme": "grundkurs_theme"
  }
}
EOF

echo "[+] Check for changes in upstream fork"
# TODO: maybe we'll switch this to main in the future
REMOTE_BRANCH="master"
COMMIT_MESSAGE="chore: add latest user changes"

echo "[+] Get current semester"
ORIGIN=$(git remote get-url origin)
SEMESTER="hs22"

if [ ${ORIGIN} != "https://renkulab.io/gitlab/grundkurs-programmieren/${SEMESTER}.git" ]
then
    echo "[+] Add upstream remote"
    git remote add upstream https://renkulab.io/gitlab/grundkurs-programmieren/${SEMESTER}.git

    # make sure we're in master branch
    git checkout ${REMOTE_BRANCH}

    echo "[+] Fetch and pull changes"
    while true; do
        git fetch upstream
        if [ $? -eq 0 ]; then
            git pull upstream ${REMOTE_BRANCH}
            break
        fi
    done

    echo "[+] Check if requirements.txt did change"
    CHANGES=$(git diff-tree --no-commit-id --name-only origin/master upstream/master)
    PIP=$( echo ${CHANGES} | awk '/requirements.txt/{print $0}' )

    if [ ! -z ${PIP} ]
    then
        echo "[+] requirements.txt changed, install new packages"
        pip install -r requirements.txt
        echo "[+] done"
    fi

    echo "[+] Adding git commit"
    git add .

    echo "[+] git status:"
    git status

    echo "[+] git diff-index:"
    # git diff-index : to avoid doing the git commit failing if there are no changes to be commit
    git diff-index --quiet HEAD || git commit --message "${COMMIT_MESSAGE}"

    # sync back to origin
    echo "[+] Pushing git commit"
    git push origin ${REMOTE_BRANCH}
else
    echo "[+] No fork detected"
fi